@@ -1,9 +1,9 @@
 {
-  "name": "faspell",
+  "name": "FaSpell",
   "version": "1.0.0",
-  "task": "SpellChecking",
-  "splits": ["faspell_main", "faspell_ocr"],
+  "task": "Spell-Checking",
+  "splits": ["main", "ocr"],
   "description": "FASpell dataset was developed for the evaluation of spell checking algorithms. It contains a set of pairs of misspelled Persian words and their corresponding corrected forms similar to the ASpell dataset used for English.",
-  "size": {"faspell_main": 5062, "faspell_ocr":  800},
+  "size": {"main": 5062, "ocr":  800},
   "filenames": ["faspell_main.txt", "faspell_ocr.txt"]
 }
